VitTableColumn class

Constructors

VitTableColumn({required String title, void onSort(bool asc)?, double width = 150, bool expandable = false, int priority = 1, EdgeInsets cellsPadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8)})

Properties

cellsPadding EdgeInsets
final
expandable bool
final
hashCode int
The hash code for this object.
no setterinherited
onSort → void Function(bool asc)?
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
width double
The width of the column.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited