expandable property
Indicates that the column can be expanded if there are extra horizontal space.
Has no effect if VitTable.enableHorizontalScroll is set to true.
Implementation
final bool expandable;
Indicates that the column can be expanded if there are extra horizontal space.
Has no effect if VitTable.enableHorizontalScroll is set to true.
final bool expandable;