width property
The width of the column.
If expandable is set to true, the this property is treated as minimum
width.
Implementation
final double width;
The width of the column.
If expandable is set to true, the this property is treated as minimum
width.
final double width;