VitTableHeaders class

Build the header of a VitTable.

Creates the text in bold of each column and draws a line below it.

Inheritance

Constructors

VitTableHeaders({Key? key, required List<VitTableColumn> columns, required VitTableStyle style, int? sortingColumnIndex, bool isAscSort = true, double? rightSpace, bool allowExpand = true})
const

Properties

allowExpand bool
Indicates that headers can expand.
final
columns List<VitTableColumn>
final
hashCode int
The hash code for this object.
no setterinherited
isAscSort bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rightSpace double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortingColumnIndex int?
final
style VitTableStyle
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited