PageNavigatorOptions class

Constructors

const

Properties

hashCode int
The hash code for this object.
no setterinherited
jumpPageOffset int
How far the page jump is set. Default is 10.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showEdgePages bool
Indicates if the first and last pages are always shown.
final
showJumpPage bool
Indicates if the jump page is shown.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited