PageNavigatorStyle class

Constructors

const

Properties

color Color?
The color used in the unselected page button.
final
hashCode int
The hash code for this object.
no setterinherited
itemSize double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color?
The color used in the selected page button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited