PageNavigatorThemeData class

Constructors

const

Properties

hashCode int
The hash code for this object.
no setterinherited
options PageNavigatorOptions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style PageNavigatorStyle
final

Methods

merge(PageNavigatorThemeData other) PageNavigatorThemeData
Merges the current PageNavigatorThemeData with another, prioritizing non-null values from the other instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited