VitTableTheme constructor
const
VitTableTheme({
- Key? key,
- required Widget child,
- required VitTableStyle data,
Creates a instance of the class that holds the logic to insert VitTableStyle into the widget tree as well as getting it using a BuildContext.
Implementation
const VitTableTheme({
super.key,
required this.child,
required this.data,
});