VitTableStyle class
Constructors
- VitTableStyle({double? height, double? minHeight, double? headerHeight, double? rowHeight, Widget? innerBottom, Widget? onEmptyWidget, RawScrollbar scrollbarBuilder(ScrollController? controller, Widget child)?, })
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerHeight → double?
-
The height of the header.
final
- height → double?
-
The exact height of the table.
final
- innerBottom → Widget?
-
The widget to show at the bottom of the table. Shown inside the table.
final
- minHeight → double?
-
The minimum height of the table.
final
- onEmptyWidget → Widget?
-
Widget to show when the table is empty
final
-
final
- rowHeight → double?
-
The height of each row.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollbarBuilder → RawScrollbar Function(ScrollController? controller, Widget child)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited